import 'dart:async';
import 'dart:convert';
import 'package:shared_preferences/shared_preferences.dart';
import 'package:sharing/remote/constants.dart';
import 'package:sharing/remote/model/application_config.dart';

final SharedPrefsHelper prefsHelper = SharedPrefsHelper();

class SharedPrefsHelper {
  static final instance = SharedPrefsHelper._internal();
  static SharedPreferences? _prefs;

  factory SharedPrefsHelper() => instance;

  SharedPrefsHelper._internal();

  Future<void> initialize() async {
    _prefs = await SharedPreferences.getInstance();
  }

  Future<void> setApplicationConfig(
      {required ApplicationConfig? applicationConfig}) async {
    if (applicationConfig != null) {
      _prefs?.setString(Constants.APPLICATION_CONFIG_CACHE,
          jsonEncode(applicationConfig.toJson()));
    } else {
      _prefs?.setString(Constants.APPLICATION_CONFIG_CACHE, "");
    }
  }

  ApplicationConfig? getApplicationConfig() {
    String? config = _prefs?.getString(Constants.APPLICATION_CONFIG_CACHE);
    if (config?.isNotEmpty == true) {
      return ApplicationConfig.fromJson(json.decode(config!));
    } else {
      return null;
    }
  }

  setThemeChange(bool isChange) =>
      _prefs?.setBool(Constants.THEME_CHANGE_CACHE, isChange);

  getThemeChange() => _prefs?.getBool(Constants.THEME_CHANGE_CACHE) ?? false;

  setThemeDefault(bool isChange) =>
      _prefs?.setBool(Constants.THEME_DEFAULT_CACHE, isChange);

  isThemeDefault() => _prefs?.getBool(Constants.THEME_DEFAULT_CACHE) ?? false;

  setDomainUrl(String value) =>
      _prefs?.setString(Constants.DOMAIN_URL_CACHE, value);

  getDomainUrl() => _prefs?.getString(Constants.DOMAIN_URL_CACHE);

  setImageUrl(String value) =>
      _prefs?.setString(Constants.IMAGE_URL_CACHE, value);

  getImageUrl() => _prefs?.getString(Constants.IMAGE_URL_CACHE);

  setLocale(String value) => _prefs?.setString(Constants.LOCALE_CACHE, value);

  getLocale() => _prefs?.getString(Constants.LOCALE_CACHE) ?? "vi";

  setFontName(String? value) =>
      _prefs?.setString(Constants.FONT_CACHE, value ?? "Roboto");

  getFontName() => _prefs?.getString(Constants.FONT_CACHE) ?? "Roboto";

  clearData() {
    _prefs?.clear();
  }
}
