import 'package:flutter/material.dart';

import '../../common/values/sizes.dart';
import '../custom/custom_icon.dart';
import '../custom/spaces.dart';
import '../dialog/custom_will_pop_back.dart';
import '../text/custom_text_large_field.dart';

class CustomAppBarArrow extends StatelessWidget {
  final String title;
  final Widget? tabBarMenu;
  final Widget? tabBarMenuRight;
  final bool? isShowShadow;
  final bool? isWarning;
  final Color? backgroundColor;
  final Color? textColor;
  final Widget? backgroundImage;
  final Widget? iconBack;
  final Function? funCallback;
  final double? heightBar;
  final int? titleMaxline;
  final double? titleTextSize;

  const CustomAppBarArrow(
      {required this.title,
      this.tabBarMenu,
      this.backgroundColor,
      this.backgroundImage,
      this.textColor,
      this.isShowShadow = false,
      this.isWarning = false,
      this.tabBarMenuRight,
      this.funCallback,
      this.iconBack,
      this.heightBar,
      this.titleMaxline = 1,
      this.titleTextSize});

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        Visibility(
          visible: backgroundImage != null,
          child: SizedBox(
              height: heightBar ?? Sizes.padingTop(context) + Sizes.HEIGHT_52,
              child: backgroundImage ?? Container()),
        ),
        Container(
            height: heightBar ?? Sizes.padingTop(context) + Sizes.HEIGHT_52,
            color: backgroundColor ?? Colors.white,
            child: appBarBody(context)),
      ],
    );
  }

  Widget appBarBody(BuildContext context) {
    return SafeArea(
      maintainBottomViewPadding: false,
      bottom: false,
      child: Column(
        children: [
          Expanded(
            child: Padding(
              padding: EdgeInsets.only(left: Sizes.MARGIN_12),
              child: GestureDetector(
                onTap: () {
                  if (funCallback != null) {
                    funCallback!();
                  } else {
                    CustomWillPopBack.Pop(context, isWarning);
                  }
                },
                child: Row(
                  crossAxisAlignment: CrossAxisAlignment.center,
                  children: <Widget>[
                    Container(
                        decoration: BoxDecoration(
                            borderRadius: BorderRadius.circular(100)),
                        child: iconBack ??
                            CustomIcon(
                              icon: Icons.keyboard_arrow_left_outlined,
                              color: textColor ?? Colors.black87,
                              size: Sizes.ICON_SIZE_32,
                            )),
                    Expanded(
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.end,
                        children: [
                          SpaceW12(),
                          Expanded(
                            child: CustomTextLargeField(
                              label: title,
                              color: textColor ?? Colors.black87,
                              textSize: titleTextSize ?? Sizes.TEXT_SIZE_18,
                              maxLine: titleMaxline,
                            ),
                          ),
                          Padding(
                            padding: EdgeInsets.only(right: Sizes.MARGIN_8),
                            child: tabBarMenuRight ?? Container(),
                          ),
                        ],
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
          tabBarMenu ?? Container(),
          if (isShowShadow == true) ...{SpaceShadowBottom()}
        ],
      ),
    );
  }
}
